@@ -1131,7 +1131,7 @@ CreatePentanucAbundance <- function(file) {
 NormalizeGenomeArg <- function(ref.genome) {
   
   if (is.null(ref.genome)) stop("Need a non-NULL ref.genome")
-  if (class(ref.genome) == "BSgenome") return(ref.genome)
+  if (inherits(ref.genome, "BSgenome")) return(ref.genome)
   
   stopifnot(class(ref.genome) == "character")
   
@@ -1709,7 +1709,7 @@ GetStrandedKmerCounts <-
 #' @param ref.genome A \code{ref.genome} argument as described in
 #'   \code{\link{ICAMS}}.
 #'
-#' @param custom.range A keyed data table which has custom ranges information. It
+#' @param custom.ranges A keyed data table which has custom ranges information. It
 #'   has three columns: chrom, start and end. It should use one-based coordinate
 #'   system. You can use the internal function in this package
 #'   \code{ICAMS:::ReadBedRanges} to read a BED file in 0-based coordinates and
